<!doctype html>

<html lang="en">
<head>
    <meta charset="utf-8">
    <title>Friskby Controlpanel</title>
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/style.css') }}">
</head>

<body>
    <header>
        <div class="logo"><img src="{{ url_for('static', filename='img/friskby-logo.png') }}"></div>
    </header>
    {% block body %}{% endblock %}
    <script src="js/scripts.js"></script>
</body>
</html>
