{% extends "base.html" %}
{% block body %}

 {% if error %}<p class="error"><strong>Error:</strong> {{ error }}{% endif %}

  <form action="{{ url_for('dashboard') }}" method="post">
    <dl>
      <dt>Device id:
      <dd><input type="text" name="deviceid">
      <dd><input type="submit" value="Register">
    </dl>
</form>

{% endblock %}
